svn commit: r318692 - in user/markj/PQ_LAUNDRY_11/usr.bin: systat top vmstat

Mark Johnston markj at FreeBSD.org
Tue May 23 04:14:36 UTC 2017


Author: markj
Date: Tue May 23 04:14:34 2017
New Revision: 318692
URL: https://svnweb.freebsd.org/changeset/base/318692

Log:
  MFC r308489, r308706:
  Add the laundry page count to the displays of systat, top, and vmstat.

Modified:
  user/markj/PQ_LAUNDRY_11/usr.bin/systat/systat.1
  user/markj/PQ_LAUNDRY_11/usr.bin/systat/vmstat.c
  user/markj/PQ_LAUNDRY_11/usr.bin/top/machine.c
  user/markj/PQ_LAUNDRY_11/usr.bin/top/top.local.1
  user/markj/PQ_LAUNDRY_11/usr.bin/vmstat/vmstat.c
Directory Properties:
  user/markj/PQ_LAUNDRY_11/   (props changed)

Modified: user/markj/PQ_LAUNDRY_11/usr.bin/systat/systat.1
==============================================================================
--- user/markj/PQ_LAUNDRY_11/usr.bin/systat/systat.1	Tue May 23 04:10:36 2017	(r318691)
+++ user/markj/PQ_LAUNDRY_11/usr.bin/systat/systat.1	Tue May 23 04:14:34 2017	(r318692)
@@ -414,7 +414,7 @@ as amounts of memory in kilobytes,
 pages wired down (`wire'),
 active pages (`act'),
 inactive pages (`inact'),
-pages on the cache queue (`cache'),
+dirty pages queued for laundering (`laund'),
 and
 free pages (`free').
 Note that the values displayed are the current transient ones;

Modified: user/markj/PQ_LAUNDRY_11/usr.bin/systat/vmstat.c
==============================================================================
--- user/markj/PQ_LAUNDRY_11/usr.bin/top/machine.c	Tue May 23 04:10:36 2017	(r318691)
+++ user/markj/PQ_LAUNDRY_11/usr.bin/top/machine.c	Tue May 23 04:14:34 2017	(r318692)
@@ -178,7 +178,7 @@ char *cpustatenames[] = {
 
 int memory_stats[7];
 char *memorynames[] = {
-	"K Active, ", "K Inact, ", "K Wired, ", "K Cache, ", "K Buf, ",
+	"K Active, ", "K Inact, ", "K Laundry, ", "K Wired, ", "K Buf, ",
 	"K Free", NULL
 };
 
@@ -521,8 +521,8 @@ get_system_info(struct system_info *si)
 		GETSYSCTL("vfs.bufspace", bufspace);
 		GETSYSCTL("vm.stats.vm.v_active_count", memory_stats[0]);
 		GETSYSCTL("vm.stats.vm.v_inactive_count", memory_stats[1]);
-		GETSYSCTL("vm.stats.vm.v_wire_count", memory_stats[2]);
-		GETSYSCTL("vm.stats.vm.v_cache_count", memory_stats[3]);
+		GETSYSCTL("vm.stats.vm.v_laundry_count", memory_stats[2]);
+		GETSYSCTL("vm.stats.vm.v_wire_count", memory_stats[3]);
 		GETSYSCTL("vm.stats.vm.v_free_count", memory_stats[5]);
 		GETSYSCTL("vm.stats.vm.v_swappgsin", nspgsin);
 		GETSYSCTL("vm.stats.vm.v_swappgsout", nspgsout);

Modified: user/markj/PQ_LAUNDRY_11/usr.bin/top/top.local.1
==============================================================================
--- user/markj/PQ_LAUNDRY_11/usr.bin/top/top.local.1	Tue May 23 04:10:36 2017	(r318691)
+++ user/markj/PQ_LAUNDRY_11/usr.bin/top/top.local.1	Tue May 23 04:14:34 2017	(r318692)
@@ -2,7 +2,7 @@
 .SH "FreeBSD NOTES"
 
 .SH DESCRIPTION OF MEMORY
-Mem: 61M Active, 86M Inact, 22G Wired, 1M Cache, 2M Buf, 102G Free
+Mem: 61M Active, 86M Inact, 1M Laundry, 22G Wired, 2M Buf, 102G Free
 ARC: 15G Total, 9303M MFU, 6155M MRU, 1464K Anon, 98M Header, 35M Other
      15G Compressed, 27G Uncompressed, 1.75:1 Ratio, 174M Overhead
 Swap: 4096M Total, 532M Free, 13% Inuse, 80K In, 104K Out
@@ -24,15 +24,14 @@ Gigabyte
 number of bytes active
 .TP
 .B Inact:
-number of bytes inactive
+number of clean bytes inactive
+.TP
+.B Laundry:
+number of dirty bytes queued for laundering
 .TP
 .B Wired:
 number of bytes wired down, including BIO-level cached file data pages
 .TP
-.B Cache:
-number of clean bytes caching data that are available for
-immediate reallocation
-.TP
 .B Buf:
 number of bytes used for BIO-level disk caching
 .TP

Modified: user/markj/PQ_LAUNDRY_11/usr.bin/vmstat/vmstat.c
==============================================================================
--- user/markj/PQ_LAUNDRY_11/usr.bin/vmstat/vmstat.c	Tue May 23 04:10:36 2017	(r318691)
+++ user/markj/PQ_LAUNDRY_11/usr.bin/vmstat/vmstat.c	Tue May 23 04:14:34 2017	(r318692)
@@ -563,7 +563,7 @@ fill_vmmeter(struct vmmeter *vmmp)
 		GET_VM_STATS(vm, v_reactivated);
 		GET_VM_STATS(vm, v_pdwakeups);
 		GET_VM_STATS(vm, v_pdpages);
-		GET_VM_STATS(vm, v_tcached);
+		GET_VM_STATS(vm, v_pdshortfalls);
 		GET_VM_STATS(vm, v_dfree);
 		GET_VM_STATS(vm, v_pfree);
 		GET_VM_STATS(vm, v_tfree);
@@ -577,7 +577,7 @@ fill_vmmeter(struct vmmeter *vmmp)
 		GET_VM_STATS(vm, v_active_count);
 		GET_VM_STATS(vm, v_inactive_target);
 		GET_VM_STATS(vm, v_inactive_count);
-		GET_VM_STATS(vm, v_cache_count);
+		GET_VM_STATS(vm, v_laundry_count);
 		GET_VM_STATS(vm, v_pageout_free_min);
 		GET_VM_STATS(vm, v_interrupt_free_min);
 		/*GET_VM_STATS(vm, v_free_severe);*/
@@ -1055,7 +1055,9 @@ dosum(void)
 		sum.v_pdwakeups);
 	xo_emit("{:page-daemon-pages/%9u} {N:pages examined by the page daemon}\n",
 		sum.v_pdpages);
-	xo_emit("{:reactivated/%9u} {N:pages reactivated}\n",
+	xo_emit("{:page-reclamation-shortfalls/%9u} {N:clean page reclamation shortfalls}\n",
+		sum.v_pdshortfalls);
+	xo_emit("{:reactivated/%9u} {N:pages reactivated by the page daemon}\n",
 		sum.v_reactivated);
 	xo_emit("{:copy-on-write-faults/%9u} {N:copy-on-write faults}\n",
 		sum.v_cow_faults);
@@ -1079,8 +1081,6 @@ dosum(void)
 		sum.v_vforkpages);
 	xo_emit("{:pages-rfork/%9u} {N:pages affected by rfork}()\n",
 		sum.v_rforkpages);
-	xo_emit("{:pages-total-cached/%9u} {N:pages cached}\n",
-		sum.v_tcached);
 	xo_emit("{:pages-freed/%9u} {N:pages freed}\n",
 		sum.v_tfree);
 	xo_emit("{:pages-freed-by-daemon/%9u} {N:pages freed by daemon}\n",
@@ -1091,8 +1091,8 @@ dosum(void)
 		sum.v_active_count);
 	xo_emit("{:inactive-pages/%9u} {N:pages inactive}\n",
 		sum.v_inactive_count);
-	xo_emit("{:vm-cache/%9u} {N:pages in VM cache}\n",
-		sum.v_cache_count);
+	xo_emit("{:laundry-pages/%9u} {N:pages in the laundry queue}\n",
+		sum.v_laundry_count);
 	xo_emit("{:wired-pages/%9u} {N:pages wired down}\n",
 		sum.v_wire_count);
 	xo_emit("{:free-pages/%9u} {N:pages free}\n",


More information about the svn-src-user mailing list
--- user/markj/PQ_LAUNDRY_11/usr.bin/systat/vmstat.c	Tue May 23 04:10:36 2017	(r318691)
+++ user/markj/PQ_LAUNDRY_11/usr.bin/systat/vmstat.c	Tue May 23 04:14:34 2017	(r318692)
@@ -92,7 +92,7 @@ static struct Info {
 	u_int v_vnodepgsin;	/* vnode_pager pages paged in */
 	u_int v_vnodepgsout;	/* vnode pager pages paged out */
 	u_int v_intrans;	/* intransit blocking page faults */
-	u_int v_reactivated;	/* number of pages reactivated from free list */
+	u_int v_reactivated;	/* number of pages reactivated by pagedaemon */
 	u_int v_pdwakeups;	/* number of times daemon has awaken from sleep */
 	u_int v_pdpages;	/* number of pages analyzed by daemon */
 
@@ -107,7 +107,7 @@ static struct Info {
 	u_int v_wire_count;	/* number of pages wired down */
 	u_int v_active_count;	/* number of pages active */
 	u_int v_inactive_count;	/* number of pages inactive */
-	u_int v_cache_count;	/* number of pages on buffer cache queue */
+	u_int v_laundry_count;	/* number of pages in laundry queue */
 	u_long v_kmem_map_size;	/* Current kmem allocation size */
 	struct	vmtotal Total;
 	struct	nchstats nchstats;
@@ -343,7 +343,7 @@ labelkre(void)
 	mvprintw(VMSTATROW + 12, VMSTATCOL + 9, "wire");
 	mvprintw(VMSTATROW + 13, VMSTATCOL + 9, "act");
 	mvprintw(VMSTATROW + 14, VMSTATCOL + 9, "inact");
-	mvprintw(VMSTATROW + 15, VMSTATCOL + 9, "cache");
+	mvprintw(VMSTATROW + 15, VMSTATCOL + 9, "laund");
 	mvprintw(VMSTATROW + 16, VMSTATCOL + 9, "free");
 	if (LINES - 1 > VMSTATROW + 17)
 		mvprintw(VMSTATROW + 17, VMSTATCOL + 9, "buf");
@@ -519,7 +519,7 @@ showkre(void)
 	putint(pgtokb(s.v_wire_count), VMSTATROW + 12, VMSTATCOL, 8);
 	putint(pgtokb(s.v_active_count), VMSTATROW + 13, VMSTATCOL, 8);
 	putint(pgtokb(s.v_inactive_count), VMSTATROW + 14, VMSTATCOL, 8);
-	putint(pgtokb(s.v_cache_count), VMSTATROW + 15, VMSTATCOL, 8);
+	putint(pgtokb(s.v_laundry_count), VMSTATROW + 15, VMSTATCOL, 8);
 	putint(pgtokb(s.v_free_count), VMSTATROW + 16, VMSTATCOL, 8);
 	if (LINES - 1 > VMSTATROW + 17)
 		putint(s.bufspace / 1024, VMSTATROW + 17, VMSTATCOL, 8);
@@ -794,7 +794,7 @@ getinfo(struct Info *ls)
 	GETSYSCTL("vm.stats.vm.v_wire_count", ls->v_wire_count);
 	GETSYSCTL("vm.stats.vm.v_active_count", ls->v_active_count);
 	GETSYSCTL("vm.stats.vm.v_inactive_count", ls->v_inactive_count);
-	GETSYSCTL("vm.stats.vm.v_cache_count", ls->v_cache_count);
+	GETSYSCTL("vm.stats.vm.v_laundry_count", ls->v_laundry_count);
 	GETSYSCTL("vfs.bufspace", ls->bufspace);
 	GETSYSCTL("kern.maxvnodes", ls->desiredvnodes);
 	GETSYSCTL("vfs.numvnodes", ls->numvnodes);

Modified: user/markj/PQ_LAUNDRY_11/usr.bin/top/machine.c
==============================================================================